@@ -43,6 +43,7 @@ from eodag.api.product.metadata_mapping import (
     DEFAULT_GEOMETRY,
     NOT_AVAILABLE,
     NOT_MAPPED,
+    ONLINE_STATUS,
 )
 from eodag.utils import (
     DEFAULT_DOWNLOAD_TIMEOUT,
@@ -62,6 +63,7 @@ if TYPE_CHECKING:
     from eodag.plugins.apis.base import Api
     from eodag.plugins.authentication.base import Authentication
     from eodag.plugins.download.base import Download
+    from eodag.plugins.manager import PluginManager
     from eodag.types.download_args import DownloadConf
     from eodag.utils import Unpack
 
@@ -143,7 +145,7 @@ class EOProduct:
             and "defaultGeometry" not in properties
         ):
             raise MisconfiguredError(
-                f"No geometry available to build EOProduct(id={properties.get('id', None)}, provider={provider})"
+                f"No geometry available to build EOProduct(id={properties.get('id')}, provider={provider})"
             )
         elif not properties["geometry"] or properties["geometry"] == NOT_AVAILABLE:
             product_geometry = properties.pop("defaultGeometry", DEFAULT_GEOMETRY)
@@ -238,6 +240,37 @@ class EOProduct:
                 f"Unable to get {e.args[0]} key from EOProduct.properties"
             )
 
+    def _register_downloader_from_manager(self, plugins_manager: PluginManager) -> None:
+        """Register the downloader and authenticator for this EOProduct using the
+        provided plugins manager.
+        This method is typically called after the EOProduct has been created and
+        before any download operation is performed.
+
+        :param plugins_manager: The plugins manager instance to use for retrieving
+                                the download and authentication plugins.
+        """
+        download_plugin = plugins_manager.get_download_plugin(self)
+        if len(self.assets) > 0:
+            matching_url = next(iter(self.assets.values()))["href"]
+        elif self.properties.get("storageStatus") != ONLINE_STATUS:
+            matching_url = self.properties.get("orderLink") or self.properties.get(
+                "downloadLink"
+            )
+        else:
+            matching_url = self.properties.get("downloadLink")
+
+        try:
+            auth_plugin = next(
+                plugins_manager.get_auth_plugins(
+                    self.provider,
+                    matching_url=matching_url,
+                    matching_conf=download_plugin.config,
+                )
+            )
+        except StopIteration:
+            auth_plugin = None
+        self.register_downloader(download_plugin, auth_plugin)
+
     def register_downloader(
         self, downloader: Union[Api, Download], authenticator: Optional[Authentication]
     ) -> None:
@@ -313,7 +346,6 @@ class EOProduct:
                 "EO product is unable to download itself due to lacking of a "
                 "download plugin"
             )
-
         auth = (
             self.downloader_auth.authenticate()
             if self.downloader_auth is not None
@@ -323,7 +355,6 @@ class EOProduct:
         progress_callback, close_progress_callback = self._init_progress_bar(
             progress_callback
         )
-
         fs_path = self.downloader.download(
             self,
             auth=auth,
@@ -369,6 +400,47 @@ class EOProduct:
         progress_callback.refresh()
         return (progress_callback, close_progress_callback)
 
+    def _download_quicklook(
+        self,
+        quicklook_file: str,
+        progress_callback: ProgressCallback,
+        ssl_verify: Optional[bool] = None,
+        auth: Optional[AuthBase] = None,
+    ):
+
+        """Download the quicklook image from the EOProduct's quicklook URL.
+
+        This method performs an HTTP GET request to retrieve the quicklook image and saves it
+        locally at the specified path. It optionally verifies SSL certificates, uses HTTP
+        authentication, and can display a download progress if a callback is provided.
+
+        :param quicklook_file: The full path (including filename) where the quicklook will be saved.
+        :param progress_callback: A callable that accepts the current and total download sizes
+                                to display or log the download progress. It must support `reset(total)`
+                                and be callable with downloaded chunk sizes.
+        :param ssl_verify: (optional) Whether to verify SSL certificates. Defaults to True.
+        :param auth: (optional) Authentication credentials (e.g., tuple or object) used for the
+                        HTTP request if the resource requires authentication.
+        :raises HTTPError: If the HTTP request to the quicklook URL fails.
+        """
+        with requests.get(
+            self.properties["quicklook"],
+            stream=True,
+            auth=auth,
+            headers=USER_AGENT,
+            timeout=DEFAULT_STREAM_REQUESTS_TIMEOUT,
+            verify=ssl_verify,
+        ) as stream:
+            stream.raise_for_status()
+            stream_size = int(stream.headers.get("content-length", 0))
+            progress_callback.reset(stream_size)
+            with open(quicklook_file, "wb") as fhandle:
+                for chunk in stream.iter_content(chunk_size=64 * 1024):
+                    if chunk:
+                        fhandle.write(chunk)
+                        progress_callback(len(chunk))
+            logger.info("Download recorded in %s", quicklook_file)
+
     def get_quicklook(
         self,
         filename: Optional[str] = None,
@@ -378,6 +450,9 @@ class EOProduct:
         """Download the quicklook image of a given EOProduct from its provider if it
         exists.
 
+        This method retrieves the quicklook URL from the EOProduct metadata and delegates
+        the download to the internal `download_quicklook` method.
+
         :param filename: (optional) The name to give to the downloaded quicklook. If not
                          given, it defaults to the product's ID (without file extension).
         :param output_dir: (optional) The absolute path of the directory where to store
@@ -403,19 +478,7 @@ class EOProduct:
                     }
                 )
 
-        # progress bar init
-        if progress_callback is None:
-            progress_callback = ProgressCallback()
-            # one shot progress callback to close after download
-            close_progress_callback = True
-        else:
-            close_progress_callback = False
-            # update units as bar may have been previously used for extraction
-            progress_callback.unit = "B"
-            progress_callback.unit_scale = True
-        progress_callback.desc = "quicklooks/%s" % self.properties.get("id", "")
-
-        if self.properties.get("quicklook", None) is None:
+        if self.properties.get("quicklook") is None:
             logger.warning(
                 "Missing information to retrieve quicklook for EO product: %s",
                 self.properties["id"],
@@ -442,6 +505,18 @@ class EOProduct:
         )
 
         if not os.path.isfile(quicklook_file):
+
+            # progress bar init
+            if progress_callback is None:
+                progress_callback = ProgressCallback()
+                # one shot progress callback to close after download
+                close_progress_callback = True
+            else:
+                close_progress_callback = False
+                # update units as bar may have been previously used for extraction
+                progress_callback.unit = "B"
+                progress_callback.unit_scale = True
+            progress_callback.desc = "quicklooks/%s" % self.properties.get("id", "")
             # VERY SPECIAL CASE (introduced by the onda provider): first check if
             # it is a HTTP URL. If not, we assume it is a base64 string, in which case
             # we just decode the content, write it into the quicklook_file and return it.
@@ -468,30 +543,25 @@ class EOProduct:
                 if self.downloader
                 else True
             )
-            with requests.get(
-                self.properties["quicklook"],
-                stream=True,
-                auth=auth,
-                headers=USER_AGENT,
-                timeout=DEFAULT_STREAM_REQUESTS_TIMEOUT,
-                verify=ssl_verify,
-            ) as stream:
-                try:
-                    stream.raise_for_status()
-                except RequestException as e:
-                    import traceback as tb
+            try:
+                self._download_quicklook(
+                    quicklook_file, progress_callback, ssl_verify, auth
+                )
+            except RequestException as e:
 
-                    logger.error("Error while getting resource :\n%s", tb.format_exc())
+                logger.debug(
+                    f"Error while getting resource with authentication. {e} \nTrying without authentication..."
+                )
+                try:
+                    self._download_quicklook(
+                        quicklook_file, progress_callback, ssl_verify, None
+                    )
+                except RequestException as e_no_auth:
+                    logger.error(
+                        f"Failed to get resource with authentication: {e} \n \
+                        Failed to get resource even without authentication. {e_no_auth}"
+                    )
                     return str(e)
-                else:
-                    stream_size = int(stream.headers.get("content-length", 0))
-                    progress_callback.reset(stream_size)
-                    with open(quicklook_file, "wb") as fhandle:
-                        for chunk in stream.iter_content(chunk_size=64 * 1024):
-                            if chunk:
-                                fhandle.write(chunk)
-                                progress_callback(len(chunk))
-                    logger.info("Download recorded in %s", quicklook_file)
 
             # close progress bar if needed
             if close_progress_callback:
@@ -518,7 +588,7 @@ class EOProduct:
         return NoDriver()
 
     def _repr_html_(self):
-        thumbnail = self.properties.get("thumbnail", None)
+        thumbnail = self.properties.get("thumbnail")
         thumbnail_html = (
             f"<img src='{thumbnail}' width=100 alt='thumbnail'/>"
             if thumbnail and not thumbnail.startswith("s3")
@@ -539,12 +609,12 @@ class EOProduct:
                         {dict_to_html_table({
                          "provider": self.provider,
                          "product_type": self.product_type,
-                         "properties[&quot;id&quot;]": self.properties.get('id', None),
+                         "properties[&quot;id&quot;]": self.properties.get('id'),
                          "properties[&quot;startTimeFromAscendingNode&quot;]": self.properties.get(
-                             'startTimeFromAscendingNode', None
+                             'startTimeFromAscendingNode'
                          ),
                          "properties[&quot;completionTimeFromAscendingNode&quot;]": self.properties.get(
-                             'completionTimeFromAscendingNode', None
+                             'completionTimeFromAscendingNode'
                          ),
                          }, brackets=False)}
                         <details><summary style='color: grey; margin-top: 10px;'>properties:&ensp;({len(
